# Changelog

All notable changes to this project will be documented in this file

## 1.0.1 - 2026-03-22

### Fixed

- Fixed incompatibility with Sphinx 9.0.0


## 1.0.0 - 2025-10-24

### Changed

- Migrated project to https://git.offworldcolonies.nexus/drewcassidy/sphinx-gha
- Updated documentation to reflect compatibility with other runners
- Changed default git ref config function to use commit SHAs instead of suggesting unpinned usage


## 0.1.1 - 2024-10-21

### Fixed

- Fixed example directive sometimes not updating `uses` values

### Changed

- Changed YAML library to ruamel in order to preserve formatting


## 0.1.0 - 2024-10-20

Initial release